@@ -14,11 +14,14 @@ from .const import (
     MQTT_PASSWORD,
     MQTT_PORT,
     MQTT_TIMEOUT,
+    MQTT_TRANSPORT,
     MQTT_USERNAME,
     MQTT_PROTOCOL,
+    MQTT_TRANSPORTS,
     VERSION,
     DEVICE_TYPE_DICT,
     FRAGMENT_DEVICE_TYPE,
+    FRAGMENT_STATE,
     TOPIC_FRAGMENTS,
     DISCOVERY_TIMEOUT_IN_SEC,
     MQTT_DISCOVER_TOPIC,
@@ -45,16 +48,25 @@ class InelsMqtt:
             config dict[str, Any]: config for mqtt connection
             host (str): mqtt broker host. Can be IP address
             port (int): broker port on which listening
+            protocol (int): mqtt version of protocol whitch will be used
+            transport (str): transportation protocol. Can be used tcp or websockets, defaltut tcp
             debug (bool): flag for debuging mqtt comunication. Default False
         """
         proto = (
             config.get(MQTT_PROTOCOL) if config.get(MQTT_PROTOCOL) else mqtt.MQTTv311
         )
 
+        _t: str = (
+            config.get(MQTT_TRANSPORT) if config.get(MQTT_TRANSPORT) else "tcp"
+        ).lower()
+
+        if _t not in MQTT_TRANSPORTS:
+            raise Exception
+
         if (client_id := config.get(MQTT_CLIENT_ID)) is None:
             client_id = mqtt.base62(uuid.uuid4().int, padding=22)
 
-        self.__client = mqtt.Client(client_id, protocol=proto)
+        self.__client = mqtt.Client(client_id, protocol=proto, transport=_t)
 
         self.__client.on_connect = self.__on_connect
         self.client.on_publish = self.__on_publish
@@ -114,7 +126,7 @@ class InelsMqtt:
             bool: Is broker available or not
         """
         self.__connect()
-        self.close()
+        self.disconnect()
 
         return self.__is_available
 
@@ -124,8 +136,8 @@ class InelsMqtt:
         """
         if self.__client.is_connected() is False:
             self.__client.connect(self.__host, self.__port)
+            self.__client.loop_start()
 
-        self.__client.loop_start()
         start_time = datetime.now()
 
         while self.__try_connect is False:
@@ -190,8 +202,6 @@ class InelsMqtt:
 
             time.sleep(0.1)
 
-        self.close()
-
         return self.__published
 
     def __on_publish(
@@ -211,7 +221,7 @@ class InelsMqtt:
         self.__published = True
         _LOGGER.info("Published: %s", mid)
 
-    def subscribe(self, topic, qos=0, options=None, properties=None) -> str:
+    def subscribe(self, topic, qos=0, options=None, properties=None) -> Any:
         """Subscribe to selected topic. Will connect, set all
         callback function and subscribe to the topic. After that
         will automatically disconnect from broker.
@@ -241,7 +251,6 @@ class InelsMqtt:
 
             time.sleep(0.1)
 
-        self.close()
         return self.__messages[topic]
 
     def discovery_all(self) -> dict[str, str]:
@@ -280,7 +289,6 @@ class InelsMqtt:
 
             time.sleep(0.1)
 
-        self.close()
         return self.__messages
 
     def __on_discover(
@@ -302,9 +310,11 @@ class InelsMqtt:
         self.__discover_start_time = datetime.now()
 
         # pass only those who belongs to known device types
-        device_type = msg.topic.split("/")[TOPIC_FRAGMENTS[FRAGMENT_DEVICE_TYPE]]
+        fragments = msg.topic.split("/")
+        device_type = fragments[TOPIC_FRAGMENTS[FRAGMENT_DEVICE_TYPE]]
+        status = fragments[TOPIC_FRAGMENTS[FRAGMENT_STATE]]
 
-        if device_type in DEVICE_TYPE_DICT:
+        if device_type in DEVICE_TYPE_DICT and status == "status":
             self.__messages[msg.topic] = msg.payload
 
     def __on_message(
@@ -349,8 +359,7 @@ class InelsMqtt:
 
     def __disconnect(self) -> None:
         """Disconnecting from broker and stopping broker's loop"""
-        if self.client.is_connected() is True:
-            self.client.loop_stop()
+        self.close()
         self.client.disconnect()
 
     def close(self) -> None:
