@@ -1,6 +1,5 @@
 """Constances of inels-mqtt."""
 from __future__ import annotations
-
 from typing import Final
 
 
@@ -47,6 +46,8 @@ DEVICE_PLATFORMS = {
     LIGHT: {LIGHT_ON: True, LIGHT_OFF: False},
 }
 
+MQTT_TRANSPORTS = {"tcp", "websockets"}
+
 MQTT_TIMEOUT: Final = "timeout"
 MQTT_HOST: Final = "host"
 MQTT_USERNAME: Final = "username"
@@ -54,6 +55,7 @@ MQTT_PASSWORD: Final = "password"
 MQTT_PORT: Final = "port"
 MQTT_CLIENT_ID: Final = "client_id"
 MQTT_PROTOCOL: Final = "protocol"
+MQTT_TRANSPORT: Final = "transport"
 PROTO_31 = "3.1"
 PROTO_311 = "3.1.1"
 PROTO_5 = 5
